canOnlySwipeFromEdge property
Whether only back gestures close to the left (LTR) or right (RTL) screen edge are counted.
This only takes effect if canSwipe ist set to true.
If set to true, this distance can be controlled via
backGestureDetectionWidth.
If set to false, the user can start dragging anywhere on the screen.
Implementation
final bool canOnlySwipeFromEdge;