SwipeablePageTransitionsBuilder class

Used by PageTransitionsTheme to define a horizontal MaterialPageRoute page transition animation that matches SwipeablePageRoute.

See SwipeablePageRoute for documentation of all properties.

⚠️ SwipeablePageTransitionsBuilder must be set for TargetPlatform.iOS. For all other platforms, you can decide whether you want to use it. This is because PageTransitionsTheme uses the builder for iOS whenever a pop gesture is in progress.

Inheritance

Constructors

SwipeablePageTransitionsBuilder({bool canOnlySwipeFromEdge = false, double backGestureDetectionWidth = kMinInteractiveDimension, double backGestureDetectionStartOffset = 0, SwipeableTransitionBuilder? transitionBuilder})
const

Properties

backGestureDetectionStartOffset double
final
backGestureDetectionWidth double
final
canOnlySwipeFromEdge bool
final
delegatedTransition DelegatedTransitionBuilder?
Provides a secondary transition to the previous route.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
reverseTransitionDuration Duration
The duration the transition going in reverse.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transitionBuilder → SwipeableTransitionBuilder?
final
transitionDuration Duration
The duration the transition going forwards.
no setterinherited

Methods

buildTransitions<T>(PageRoute<T> route, BuildContext context, Animation<double> animation, Animation<double> secondaryAnimation, Widget child) Widget
Wraps the child with one or more transition widgets which define how route arrives on and leaves the screen.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited